import { createRouter, createWebHistory } from 'vue-router';
import store from '@/stores/counter';
import axios from 'axios';

import common from './module/common';
import dock from './module/dock';
import channel from './module/channel';
import train from './module/train';

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      redirect: '/homeIndex'
    },
    {
      path: '/homeIndex',
      meta: { title: '中科在线（长春）' },
      component: () => import('@common/src/components/live-frame/home.vue'),
      children: [
        {
          path: '/homeIndex',
          meta: { title: '中科在线（长春）' },
          component: () => import('@/views/home/index.vue')
        },
        ...common,
        ...dock,
        ...channel,
        ...train
      ]
    }
  ]
});
router.beforeEach(async (to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (token) {
    const res = await axios.request({
      method: 'get',
      url: '/zkzx/v2/api/token/tokenView',
      responseType: 'json',
      headers: {
        token: token
      }
    });
    if (res.data.errcode == '0') {
      store.commit('setUser', res.data.data, { root: true });
    }
    next();
  } else {
    window.alert('无登录信息，无法打开');
  }
});

export default router;
